@@ -39,6 +39,7 @@ Example of an empty ``scm``:
 import logging
 import xml.etree.ElementTree as XML
 
+from jenkins_jobs.loc_loader import LocList
 from jenkins_jobs.errors import InvalidAttributeError
 from jenkins_jobs.errors import JenkinsJobsException
 import jenkins_jobs.modules.base
@@ -221,7 +222,7 @@ def git(registry, xml_parent, data):
 
         :browsers supported:
             * **auto** - (default)
-            * **assemblaweb** - https://www.assembla.com/home
+            * **assemblaweb** - https://get.assembla.com/
             * **bitbucketweb** - https://bitbucket.org/
             * **cgit** - https://git.zx2c4.com/cgit/about/
             * **fisheye** - https://www.atlassian.com/software/fisheye
@@ -229,10 +230,10 @@ def git(registry, xml_parent, data):
             * **githubweb** - https://github.com/
             * **gitiles** - https://code.google.com/archive/p/gitiles/
             * **gitlab** - https://about.gitlab.com/
-            * **gitlist** - http://gitlist.org/
+            * **gitlist** - https://gitlist.org/
             * **gitoriousweb** - https://gitorious.org/
             * **gitweb** - https://git-scm.com/docs/gitweb
-            * **kiln** - https://www.fogbugz.com/version-control
+            * **kiln** - https://ignitetech.com/softwarelibrary/fogbugz
             * **microsoft\-tfs\-2013** - |tfs_2013|
             * **phabricator** - https://www.phacility.com/
             * **redmineweb** - https://www.redmine.org/
@@ -344,7 +345,7 @@ def git(registry, xml_parent, data):
     .. literalinclude:: /../../tests/scm/fixtures/git001.yaml
 
     .. |tfs_2013| replace::
-        https://azure.microsoft.com/en-us/services/devops/server
+        https://azure.microsoft.com/en-us/products/devops/server/
 
     """
     logger = logging.getLogger("%s:git" % __name__)
@@ -1371,8 +1372,8 @@ def hg(self, xml_parent, data):
             * **bitbucketweb** - https://bitbucket.org/
             * **fisheye** - https://www.atlassian.com/software/fisheye
             * **googlecode** - https://code.google.com/
-            * **hgweb** - https://www.mercurial-scm.org/repo/hg/help/hgweb
-            * **kilnhg** - https://www.fogbugz.com/version-control
+            * **hgweb** - https://repo.mercurial-scm.org/hg/help/hgweb
+            * **kilnhg** - https://ignitetech.com/softwarelibrary/fogbugz
             * **rhodecode** - https://rhodecode.com/ (versions >= 1.2)
             * **rhodecode-pre-1.2.0** - https://rhodecode.com/ (versions < 1.2)
 
@@ -1769,8 +1770,8 @@ class SCM(jenkins_jobs.modules.base.Base):
             return
 
         scms_parent = XML.Element("scms")
-        for scm in data.get("scm", []):
-            self.registry.dispatch("scm", scms_parent, scm)
+        component_list = data.get("scm", [])
+        self.dispatch_component_list("scm", component_list, scms_parent)
         scms_count = len(scms_parent)
         if scms_count == 0:
             XML.SubElement(xml_parent, "scm", {"class": "hudson.scm.NullSCM"})
@@ -1806,7 +1807,14 @@ class PipelineSCM(jenkins_jobs.modules.base.Base):
             if scms_count == 0:
                 raise JenkinsJobsException("'scm' missing or empty")
             elif scms_count == 1:
-                self.registry.dispatch("scm", definition_parent, scms[0])
+                component = scms[0]
+                if isinstance(scms, LocList):
+                    component_pos = scms.value_pos[0]
+                else:
+                    component_pos = None
+                self.registry.dispatch(
+                    "scm", definition_parent, component, component_pos=component_pos
+                )
                 mapping = [
                     ("script-path", "scriptPath", "Jenkinsfile"),
                     ("lightweight-checkout", "lightweight", None, [True, False]),
